Applicative<A> mixin

Provides the application of a function in an Applicative context to a value in an Applicative context.

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ap<B>(Applicative<Function1<A, B>> f) Applicative<B>
Apply f to the value of this Applicative.
map<B>(Function1<A, B> f) Functor<B>
Applies f to the value of this Functor.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited