collect<B> method
Returns a new collection by applying f to each element an only keeping
results of type Some.
Implementation
@override
ArrayDeque<B> collect<B>(Function1<A, Option<B>> f) => from(super.collect(f));
Returns a new collection by applying f to each element an only keeping
results of type Some.
@override
ArrayDeque<B> collect<B>(Function1<A, Option<B>> f) => from(super.collect(f));