diff method
Returns a new collection with the difference of this and that, i.e.
all elements that appear in only this collection.
Implementation
@override
ArrayDeque<A> diff(RSeq<A> that) => from(super.diff(that));
Returns a new collection with the difference of this and that, i.e.
all elements that appear in only this collection.
@override
ArrayDeque<A> diff(RSeq<A> that) => from(super.diff(that));