trimToSize method
void
trimToSize()
Shrinks the internal array to exactly fit the current number of elements.
Implementation
void trimToSize() => _resize(length);
Shrinks the internal array to exactly fit the current number of elements.
void trimToSize() => _resize(length);