isTraversableAgain property
Whether this collection can be traversed more than once.
Always false for a bare RIterableOnce; overridden to true by
RIterable and its subtypes.
Implementation
bool get isTraversableAgain => false;
Whether this collection can be traversed more than once.
Always false for a bare RIterableOnce; overridden to true by
RIterable and its subtypes.
bool get isTraversableAgain => false;