lift method

Option<A> lift(
  1. int ix
)
inherited

Returns the element at index ix as a Some. If ix is outside the range of this collection, None is returned.

Implementation

Option<A> lift(int ix) => Option.when(() => isDefinedAt(ix), () => this[ix]);