reduceRightOption method

Option<A> reduceRightOption(
  1. Function2<A, A, A> op
)
inherited

Returns a summary values of all elements of this collection by applying f to each element, moving right to left.

If this collection is empty, None will be returned.

Implementation

Option<A> reduceRightOption(Function2<A, A, A> op) => switch (knownSize) {
  -1 => _reduceOptionIterator(_reversed().iterator, (x, y) => op(y, x)),
  0 => none(),
  _ => Some(reduceRight(op)),
};