takeRight method

RIterable<A> takeRight(
  1. int n
)
inherited

Returns a new collection with the last n elements of this collection. If n is greater than the size of this collection, the original collection is returned.

Implementation

RIterable<A> takeRight(int n) => views.TakeRight(this, n);