Cons<A> class
final
- Inheritance
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- head → A
-
Returns the first element of this collection, or throws if it is empty.
final
-
headOption
→ Option<
A> -
Returns the first element of this collection as a Some if non-empty.
If this collction is empty, None is returned.
no setteroverride
-
init
→ IList<
A> -
Returns all elements from this collection except the last. If this
collection is empty, an empty collection is returned.
no setterinherited
-
inits
→ RIterator<
IList< A> > -
Returns an iterator of all potential tails of this collection, starting
with the entire collection and ending with an empty one.
no setterinherited
- isEmpty → bool
-
Whether this collection contains no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection contains at least one element.
no setterinherited
- isTraversableAgain → bool
-
Whether this collection can be traversed more than once.
no setterinherited
-
iterator
→ RIterator<
A> -
Returns an RIterator over the elements of this collection.
no setterinherited
- knownSize → int
-
Returns the number of elements in this collection, if that number is
already known. If not, -1 is returned.
no setterinherited
- last → A
-
Returns the last element of this collection, or throws if it is empty.
no setterinherited
-
lastOption
→ Option<
A> -
Returns the last element of this collection as a Some, or None if this
collection is empty.
no setterinherited
- length → int
-
The number of elements in this sequence.
no setterinherited
- nonEmpty → bool
-
Whether this collection contains at least one element.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Returns the number of elements in this collection.
no setterinherited
-
tail
→ IList<
A> -
Returns a new collection with the first element removed. If this
collection is empty, an empty collection is returned.
no setteroverride
-
tails
→ RIterator<
IList< A> > -
Returns an iterator of all potential tails of this collection, starting
with the entire collection and ending with an empty one.
no setterinherited
Methods
-
appended(
A elem) → IList< A> -
Returns a new Seq, with the given
elemadded to the end.inherited -
appendedAll(
RIterableOnce< A> suffix) → IList<A> -
Returns a new Seq, with
elemsadded to the end.inherited -
canEqual(
Object other) → bool -
inherited
-
collect<
B> (Function1< A, Option< f) → IList<B> >B> -
Returns a new collection by applying
fto each element an only keeping results of type Some.inherited -
collectFirst<
B> (Function1< A, Option< f) → Option<B> >B> -
Applies
fto each element of this collection, returning the first element that results in a Some, if any.inherited -
combinations(
int n) → RIterator< IList< A> > -
Returns an Iterator that will produce all combinations of elements from
this sequence of size
nin order.inherited -
concat(
covariant RIterableOnce< A> suffix) → IList<A> -
Returns a copy of this collection, with
elemsadded to the end.inherited -
contains(
A elem) → bool -
Returns true, if any element of this collection equals
elem.inherited -
containsSlice(
RSeq< A> that) → bool -
Returns true if
thatis contained in this collection, in order.inherited -
copyToArray(
Array< A> xs, [int start = 0, int? n]) → int -
Copies elements into
xsstarting atstart, writing at mostnelements (or all remaining capacity whennis omitted).inherited -
corresponds<
B> (covariant RSeq< B> that, Function2<A, B, bool> p) → bool -
Returns true if this collection has the same size as
thatand each corresponding element from this andthatsatisfies the given predicatep.inherited -
count(
Function1< A, bool> p) → int -
Return the number of elements in this collection that satisfy the given
predicate.
inherited
-
deleteFirst(
Function1< A, bool> p) → Option<(A, IList< A> )> -
Removes the first element satisfying
pand returns it paired with the remaining list. Returns None if no element matches.inherited -
diff(
RSeq< A> that) → IList<A> -
Returns a new collection with the difference of this and
that, i.e. all elements that appear in only this collection.inherited -
distinct(
) → IList< A> -
Returns a new collection where every element is distinct according to
equality.
inherited
-
distinctBy<
B> (Function1< A, B> f) → IList<A> -
Returns a new collection where every element is distinct according to
the application of
fto each element.inherited -
drop(
int n) → IList< A> -
Returns a new collection with the first
nelements removed.inherited -
dropRight(
int n) → IList< A> -
Return a new collection with the last
nelements removed.inherited -
dropWhile(
Function1< A, bool> p) → IList<A> -
Returns a new collection with leading elements satisfying
premoved.inherited -
dropWhileN(
Function5< T1, T2, T3, T4, T5, bool> p) → IList<(T1, T2, T3, T4, T5)> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
dropWhileN(
Function4< T1, T2, T3, T4, bool> p) → IList<(T1, T2, T3, T4)> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
dropWhileN(
Function3< T1, T2, T3, bool> p) → IList<(T1, T2, T3)> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
dropWhileN(
Function2< T1, T2, bool> p) → IList<(T1, T2)> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
endsWith(
RIterable< A> that) → bool -
Returns true if the end of this collection has the same elements in order
as
that. Otherwise, false is returned.inherited -
exists(
Function1< A, bool> p) → bool -
Returns true if any element of this collection satisfies the given
predicate, false if no elements satisfy it.
inherited
-
filter(
Function1< A, bool> p) → IList<A> -
Returns a new collection containing only elements that satisfy
p.inherited -
filterN(
Function5< T1, T2, T3, T4, T5, bool> p) → IList<(T1, T2, T3, T4, T5)> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
filterN(
Function4< T1, T2, T3, T4, bool> p) → IList<(T1, T2, T3, T4)> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
filterN(
Function3< T1, T2, T3, bool> p) → IList<(T1, T2, T3)> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
filterN(
Function2< T1, T2, bool> p) → IList<(T1, T2)> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
filterNot(
Function1< A, bool> p) → IList<A> -
Returns a new collection containing only elements that do not
satisfy
p.inherited -
filterNotN(
Function5< T1, T2, T3, T4, T5, bool> p) → IList<(T1, T2, T3, T4, T5)> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
filterNotN(
Function4< T1, T2, T3, T4, bool> p) → IList<(T1, T2, T3, T4)> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
filterNotN(
Function3< T1, T2, T3, bool> p) → IList<(T1, T2, T3)> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
filterNotN(
Function2< T1, T2, bool> p) → IList<(T1, T2)> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
find(
Function1< A, bool> p) → Option<A> -
Returns the first element from this collection that satisfies the given
predicate
p. If no element satisfiesp, None is returned.inherited -
findLast(
Function1< A, bool> p) → Option<A> -
Returns the last element satisfying
pasSome, or None if none.inherited -
flatMap<
B> (covariant Function1< A, RIterableOnce< f) → IList<B> >B> -
Returns a new collection by applying
fto each element and concatenating the results.inherited -
flatMapN<
T6> (Function5< T1, T2, T3, T4, T5, IList< f) → IList<T6> >T6> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
flatMapN<
T5> (Function4< T1, T2, T3, T4, IList< f) → IList<T5> >T5> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
flatMapN<
T4> (Function3< T1, T2, T3, IList< f) → IList<T4> >T4> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
flatMapN<
T3> (Function2< T1, T2, IList< f) → IList<T3> >T3> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
flatten(
) → RIterable< A> -
Available on RIterable<
Concatenates all inner iterables into a single IList.RIterable< , provided by the RIterableNested2Ops extensionA> > -
flatten(
) → IList< A> -
Available on IList<
Combines all nested lists into one list using concatenation.IList< , provided by the IListNestedOps extensionA> > -
fold(
A init, Function2< A, A, A> op) → A -
Alias for foldLeft with a same-type accumulator.
inherited
-
foldLeft<
B> (B z, Function2< B, A, B> op) → B -
Returns a summary value by applying
opto all elements of this collection, moving from left to right. The fold uses a seed value ofz.inherited -
foldRight<
B> (B z, Function2< A, B, B> op) → B -
Returns a summary value by applying
opto all elements of this collection, moving from right to left. The fold uses a seed value ofz.inherited -
forall(
Function1< A, bool> p) → bool -
Returns true if all elements of this collection satisfy the given
predicate, false if any elements do not.
inherited
-
foreach<
U> (Function1< A, U> f) → void -
Applies
fto each element of this collection, discarding any resulting values.inherited -
foreachN(
Function3< T1, T2, T3, void> f) → void -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
foreachN(
Function5< T1, T2, T3, T4, T5, void> f) → void -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
foreachN(
Function4< T1, T2, T3, T4, void> f) → void -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
foreachN(
Function2< T1, T2, void> f) → void -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
groupBy<
K> (Function1< A, K> f) → IMap<K, IList< A> > -
Partitions all elements of this collection by applying
fto each element and accumulating duplicate keys in the returned IMap.inherited -
grouped(
int size) → RIterator< IList< A> > -
Returns a new iterator where each element is a collection of
sizeelements from the original collection. The last element may contain less thansizeelements.inherited -
groupMap<
K, B> (Function1< A, K> key, Function1<A, B> f) → IMap<K, IList< B> > -
Creates a new map by generating a key-value pair for each elements of this
collection using
keyandf. Any elements that generate the same key will have the resulting values accumulated in the returned map.inherited -
groupMapReduce<
K, B> (Function1< A, K> key, Function1<A, B> f, Function2<B, B, B> reduce) → IMap<K, B> -
Partitions all elements of this collection by applying
keyto each element. Additionallyfis applied to each element to generate a value. If multiple values are generating for the same key, those values will be combined usingreduce.inherited -
indexOf(
A elem, [int from = 0]) → Option< int> -
Returns the first index, if any, where the element at that index equals
elem. If no index containselem, None is returned.inherited -
indexOfSlice(
RSeq< A> that, [int from = 0]) → Option<int> -
Finds the first index in this collection where the next sequence of
elements is equal to
that. Ifthatcannot be found in this collection, None is returned.inherited -
indexWhere(
Function1< A, bool> p, [int from = 0]) → Option<int> -
Returns the index of the first element that satisfies the predicate
p. If no element satisfies, None is returned.inherited -
indices(
) → Range -
Returns a range of all indices of this sequence
inherited
-
insertAt(
int idx, A elem) → IList< A> -
Returns a new list with
eleminserted atidx.inherited -
intersect(
RSeq< A> that) → IList<A> -
Returns a new collection with the intersection of this and
that, i.e. all elements that appear in both collections.inherited -
intersperse(
A x) → IList< A> -
Returns a new collection with
sepinserted between each element.inherited -
isDefinedAt(
int idx) → bool -
Returns true if this collection has an element at the given
idx.inherited -
lastIndexOf(
A elem, [int end = 2147483647]) → Option< int> -
Returns the last index, if any, where the element at that index equals
elem. If no index containselem, None is returned.inherited -
lastIndexOfSlice(
RSeq< A> that, [int end = 2147483647]) → Option<int> -
Finds the last index in this collection where the next sequence of
elements is equal to
that. Ifthatcannot be found in this collection, None is returned.inherited -
lastIndexWhere(
Function1< A, bool> p, [int end = 2147483647]) → Option<int> -
Returns the index of the last element that satisfies the predicate
p. If no element satisfies, None is returned.inherited -
lift(
int ix) → Option< A> -
Returns the element at index
ixas a Some. Ifixis outside the range of this collection, None is returned.inherited -
map<
B> (Function1< A, B> f) → IList<B> -
Returns a new collection by applying
fto each element.inherited -
mapN<
T6> (Function5< T1, T2, T3, T4, T5, T6> f) → IList<T6> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
mapN<
T3> (Function2< T1, T2, T3> f) → IList<T3> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
mapN<
T5> (Function4< T1, T2, T3, T4, T5> f) → IList<T5> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
mapN<
T4> (Function3< T1, T2, T3, T4> f) → IList<T4> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
maxByOption<
B> (Function1< A, B> f, Order<B> order) → Option<A> -
Finds the largest element in this collection by applying
fto each element and using the given Order to find the greatest.inherited -
maxOption(
Order< A> order) → Option<A> -
Finds the largest element in this collection according to the given
Order.
inherited
-
minByOption<
B> (Function1< A, B> f, Order<B> order) → Option<A> -
Finds the smallest element in this collection by applying
fto each element and using the given Order to find the greatest.inherited -
minOption(
Order< A> order) → Option<A> -
Finds the largest element in this collection according to the given
Order.
inherited
-
mkString(
{String? start, String? sep, String? end}) → String -
Returns a String by using each elements toString(), adding
sepbetween each element. Ifstartis defined, it will be prepended to the resulting string. Ifendis defined, it will be appended to the resulting string.inherited -
noNulls(
) → IList< A> -
Available on IList<
Returns a new list with all null elements removed.A?> , provided by the IListNullableOps extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padTo(
int len, A elem) → IList< A> -
Returns a new collection with a length of at least
len.inherited -
partition(
Function1< A, bool> p) → (IList<A> , IList<A> ) -
Returns 2 collections as a tuple where the first tuple element will be a
collection of elements that satisfy the given predicate
p. The second item of the returned tuple will be elements that do not satisfyp.inherited -
partitionMap<
A1, A2> (Function1< A, Either< f) → (IList<A1, A2> >A1> , IList<A2> ) -
Applies
fto each element of this collection and returns a separate collection for all applications resulting in a Left and Right respectively.inherited -
patch(
int from, RIterableOnce< A> other, int replaced) → IList<A> -
Returns a new collection with
replacedelements starting atfromreplaced by the elements ofother.inherited -
permutations(
) → RIterator< IList< A> > -
Returns an Iterator that will emit all possible permutations of the
elements in this collection.
inherited
-
prepended(
A elem) → IList< A> -
Returns a new collection with
elemadded to the beginning.inherited -
prependedAll(
RIterableOnce< A> prefix) → IList<A> -
Returns a new collection with all
elemsadded to the beginning.inherited -
product(
) → int -
Available on RIterableOnce<
Returns the product of all elements in this listint> , provided by the RIterableIntOps extension -
product(
) → double -
Available on RIterableOnce<
Returns the product of all elements in this listdouble> , provided by the RIterableDoubleOps extension -
reduce(
Function2< A, A, A> op) → A -
Reduces this collection to a single value by applying
opleft to right.inherited -
reduceLeft(
Function2< A, A, A> op) → A -
Reduces from left to right. Throws if empty.
inherited
-
reduceLeftOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving left to right.inherited -
reduceOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving left to right.inherited -
reduceRight(
Function2< A, A, A> op) → A -
Reduces from right to left. Throws if empty.
inherited
-
reduceRightOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving right to left.inherited -
removeAt(
int idx) → IList< A> -
Returns a new collection with the element at
idxremoved.inherited -
removeFirst(
Function1< A, bool> p) → IList<A> -
Returns a new list with the first element satisfying
premoved.inherited -
reverse(
) → IList< A> -
Returns a new collection with the order of the elements reversed.
inherited
-
reverseIterator(
) → RIterator< A> -
Returns an iterator that will emit all elements in this collection, in
reverse order.
inherited
-
sameElements(
RIterable< A> that) → bool -
Returns true if this collection has the same elements, in the same order,
as
that.inherited -
scan<
B> (B z, Function2< B, A, B> op) → IList<B> -
Alias for scanLeft.
inherited
-
scanLeft<
B> (B z, Function2< B, A, B> op) → IList<B> -
Returns a new collection of running totals starting with
z.inherited -
scanRight<
B> (B z, Function2< A, B, B> op) → IList<B> -
Returns a new collection of running totals starting with
z, traversing from right to left.inherited -
segmentLength(
Function1< A, bool> p, [int from = 0]) → int -
Returns the length of the longest prefix starting at
fromwhere every element satisfiesp.inherited -
sequence(
) → Option< IList< A> > -
Available on IList<
Accumulates all elements in this list as one Option. If any element is a None, None will be returned. If all elements are Some, then the entire list is returned, wrapped in a Some.Option< , provided by the IListOptionOps extensionA> > -
sequence(
) → Either< A, IList< B> > -
Available on IList<
Accumulates all elements in this list as one Either. If any element is a Left, that Left is returned immediately. If all elements are Right, the entire list of right values is returned wrapped in a Right.Either< , provided by the IListEitherOps extensionA, B> > -
slice(
int from, int until) → IList< A> -
Returns a new collection containing elements in the range
[from, until).inherited -
sliding(
int size, [int step = 1]) → RIterator< IList< A> > -
Returns an iterator where elements are fixed size chunks of size
nof the original collection. Each chunk is calculated by sliding a 'window' of sizenover the original collection, moving the windowstepelements at a time.inherited -
sortBy<
B> (Order< B> order, Function1<A, B> f) → IList<A> -
Returns a new collection that is sorted according to
orderafter applyingfto each element in this collection.inherited -
sorted(
Order< A> order) → IList<A> -
Returns a new collection that is sorted according to
order.inherited -
sortWith(
Function2< A, A, bool> lt) → IList<A> -
Returns a new collection sorted using the provided function
ltwhich is used to determine if one element is less than the other.inherited -
span(
Function1< A, bool> p) → (IList<A> , IList<A> ) -
Returns two collections: elements before and starting from the first
element that does not satisfy
p.inherited -
splitAt(
int n) → (IList< A> , IList<A> ) -
Returns two collections: the first
nelements and the remainder.inherited -
startsWith(
RIterableOnce< A> that, [int offset = 0]) → bool -
Returns true if the beginning of this collection corresponds with
that.inherited -
sum(
) → int -
Available on RIterableOnce<
Returns the sum of all elements in this listint> , provided by the RIterableIntOps extension -
sum(
) → double -
Available on RIterableOnce<
Returns the sum of all elements in this listdouble> , provided by the RIterableDoubleOps extension -
take(
int n) → IList< A> -
Returns a new collection containing only the first
nelements.inherited -
takeRight(
int n) → IList< A> -
Returns a new collection with the last
nelements of this collection. Ifnis greater than the size of this collection, the original collection is returned.inherited -
takeWhile(
Function1< A, bool> p) → IList<A> -
Returns a new collection of leading elements that satisfy
p.inherited -
takeWhileN(
Function2< T1, T2, bool> p) → IList<(T1, T2)> -
Available on IList<
(T1, T2)> , provided by the IListTuple2Ops extension -
takeWhileN(
Function4< T1, T2, T3, T4, bool> p) → IList<(T1, T2, T3, T4)> -
Available on IList<
(T1, T2, T3, T4)> , provided by the IListTuple4Ops extension -
takeWhileN(
Function5< T1, T2, T3, T4, T5, bool> p) → IList<(T1, T2, T3, T4, T5)> -
Available on IList<
(T1, T2, T3, T4, T5)> , provided by the IListTuple5Ops extension -
takeWhileN(
Function3< T1, T2, T3, bool> p) → IList<(T1, T2, T3)> -
Available on IList<
(T1, T2, T3)> , provided by the IListTuple3Ops extension -
tapEach<
U> (Function1< A, U> f) → IList<A> -
Applies
fto each element in this collection, discarding any results and returns this collection.inherited -
toIList(
) → IList< A> -
Returns an IList with the same elements as this collection.
inherited
-
toIMap(
) → IMap< A, B> -
Available on RIterable<
Creates a new IMap where each tuple element of this list is used to create a key and value respectively.(A, B)> , provided by the RIterableTuple2Ops extension -
toIndexedSeq(
) → IndexedSeq< A> -
Returns an IndexedSeq with the same elements as this collection.
inherited
-
toISet(
) → ISet< A> -
Returns an ISet with the same elements as this collection, duplicates
removed.
inherited
-
toIVector(
) → IVector< A> -
Returns an IVector with the same elements as this collection.
inherited
-
toList(
{bool growable = true}) → List< A> -
Returns a new List with the same elements as this collection.
inherited
-
toNel(
) → Option< NonEmptyIList< A> > -
Converts this list to a NonEmptyIList, returning None if it is empty.
inherited
-
toSeq(
) → RSeq< A> -
Returns a RSeq with the same elements as this collection.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
traverseEither<
B, C> (Function1< A, Either< f) → Either<B, C> >B, IList< C> > -
Applies
fto each element of this RSeq and collects the results into a new collection. If Left is encountered for any element, that result is returned and any additional elements will not be evaluated.inherited -
traverseOption<
B> (Function1< A, Option< f) → Option<B> >IList< B> > -
Applies
fto each element of this RSeq and collects the results into a new collection. If None is encountered for any element, that result is returned and any additional elements will not be evaluated.inherited -
uncons<
B> (Function1< Option< f) → B(A, IList< , B>A> )> -
Deconstructs the list by passing
Some((head, tail))tofwhen non-empty, orNonewhen empty.inherited -
unNone(
) → IList< A> -
Available on IList<
Returns a new list with all None elements removed.Option< , provided by the IListOptionOps extensionA> > -
unzip(
) → (IList< A> , IList<B> , IList<C> ) -
Available on IList<
Returns 3 new lists as a tuple. The first list is all the first items from each tuple element of this list. The second list is all the second items from each tuple element of this list. The third list is all the third items from each tuple element of this list.(A, B, C)> , provided by the IListTuple3UnzipOps extension -
unzip(
) → (IList< A> , IList<B> ) -
Available on IList<
Returns 2 new lists as a tuple. The first list is all the Left items from each element of this list. The second list is all the Right items from each element of this list.Either< , provided by the IListEitherOps extensionA, B> > -
unzip(
) → (RIterable< A> , RIterable<B> ) -
Available on RIterable<
Splits a collection of pairs into two separate collections.(A, B)> , provided by the RibsIterableTuple2Ops extension -
unzip(
) → (IList< A> , IList<B> ) -
Available on IList<
Returns 2 new lists as a tuple. The first list is all the first items from each tuple element of this list. The second list is all the second items from each tuple element of this list.(A, B)> , provided by the IListTuple2UnzipOps extension -
updated(
int index, A elem) → IList< A> -
Returns a new collection with the element at
indexreplaced byelem.inherited -
zip<
B> (RIterableOnce< B> that) → IList<(A, B)> -
Returns a new collection that combines corresponding elements from this
collection and
thatas a tuple. The length of the returned collection will be the minimum of this collections size and the size ofthat.inherited -
zipAll<
B> (RIterableOnce< B> that, A thisElem, B thatElem) → IList<(A, B)> -
Returns a new collection that combines corresponding elements from this
collection and
thatas a tuple. The length of the returned collection will be the maximum of this collections size and thes size ofthat. If this collection is shorter thanthat,thisElemwill be used to fill in the resulting collection. Ifthatis shorter,thatElemwill be used to will in the resulting collection.inherited -
zipWithIndex(
) → IList< (A, int)> -
Return a new collection with each element of this collection paired with
it's respective index.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int idx) → A -
Returns the element at index
idx.inherited