Fn1<A, B> class final

A nominal wrapper around a one-argument function A -> B.

See the file-level documentation for the motivation behind these wrappers.

Constructors

Fn1(Function1<A, B> f)
const

Properties

f Function1<A, B>
The underlying function.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(A a) → B
Invokes the underlying function with a and returns its result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited