Function9Ops<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> extension
Provides additional functions on functions with 9 parameters.
- on
-
- Function9<
T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>
- Function9<
Properties
-
curried
→ Function9C<
T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> -
Available on Function9<
Return the curried form of this function.T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> , provided by the Function9Ops extensionno setter -
tupled
→ Function1<
(T0, T1, T2, T3, T4, T5, T6, T7, T8), T9> -
Available on Function9<
Returns a function that takes a tuple of parameters rather than individual parameters.T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> , provided by the Function9Ops extensionno setter
Methods
-
andThen<
T10> (Function1< T9, T10> fn) → Function9<T0, T1, T2, T3, T4, T5, T6, T7, T8, T10> -
Available on Function9<
Composes this function with the provided function, this function being applied first.T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> , provided by the Function9Ops extension -
compose<
T10> (Function1< T10, (T0, T1, T2, T3, T4, T5, T6, T7, T8)> fn) → Function1<T10, T9> -
Available on Function9<
Composes this function with the provided function, this function being applied first.T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> , provided by the Function9Ops extension