IListTuple2UnzipOps<A, B> extension

Unzip operations for IList of 2-tuples.

on

Methods

unzip() → (IList<A>, IList<B>)

Available on IList<(A, B)>, provided by the IListTuple2UnzipOps extension

Returns 2 new lists as a tuple. The first list is all the first items from each tuple element of this list. The second list is all the second items from each tuple element of this list.