builder<A> static method
Returns a mutable builder that accumulates elements into an IVector.
Implementation
static IVectorBuilder<A> builder<A>() => IVectorBuilder();
Returns a mutable builder that accumulates elements into an IVector.
static IVectorBuilder<A> builder<A>() => IVectorBuilder();