partitionMap<A1, A2> method

  1. @override
(IVector<A1>, IVector<A2>) partitionMap<A1, A2>(
  1. Function1<A, Either<A1, A2>> f
)
override

Applies f to each element of this collection and returns a separate collection for all applications resulting in a Left and Right respectively.

Implementation

@override
(IVector<A1>, IVector<A2>) partitionMap<A1, A2>(
  Function1<A, Either<A1, A2>> f,
) {
  final (a, b) = super.partitionMap(f);
  return (a.toIVector(), b.toIVector());
}