last property
Returns the last element of this collection, or throws if it is empty.
Implementation
@override
A get last {
if (_last0 == null) {
throw StateError('last of empty ListBuffer');
} else {
return _last0!.head;
}
}
Returns the last element of this collection, or throws if it is empty.
@override
A get last {
if (_last0 == null) {
throw StateError('last of empty ListBuffer');
} else {
return _last0!.head;
}
}