put method

  1. @override
Option<V> put(
  1. K key,
  2. V value
)
override

Associates key with value, returning the previous value as Some, or None if key was not present.

Implementation

@override
Option<V> put(K key, V value) => _put0b(key, value, true) ?? none();