getOrElse method
Returns the value for the given key key, or orElse if this map doesn't
contain the key.
Implementation
V getOrElse(K key, Function0<V> orElse) => get(key).getOrElse(orElse);
Returns the value for the given key key, or orElse if this map doesn't
contain the key.
V getOrElse(K key, Function0<V> orElse) => get(key).getOrElse(orElse);