reduce method
Reduces this collection to a single value by applying op left to right.
Throws if the collection is empty.
Implementation
A reduce(Function2<A, A, A> op) => reduceLeft(op);
Reduces this collection to a single value by applying op left to right.
Throws if the collection is empty.
A reduce(Function2<A, A, A> op) => reduceLeft(op);