enqueueAll method
Adds all elems at the back of the queue and returns this.
Implementation
MQueue<A> enqueueAll(RIterableOnce<A> elems) {
super.addAll(elems);
return this;
}
Adds all elems at the back of the queue and returns this.
MQueue<A> enqueueAll(RIterableOnce<A> elems) {
super.addAll(elems);
return this;
}