flatMap<B> method
Returns a new collection by applying f to each element and
concatenating the results.
Implementation
@override
RIterator<B> flatMap<B>(Function1<A, RIterableOnce<B>> f) => _FlatMapIterator(this, f);
Returns a new collection by applying f to each element and
concatenating the results.
@override
RIterator<B> flatMap<B>(Function1<A, RIterableOnce<B>> f) => _FlatMapIterator(this, f);