maxByOption<B> method

Option<A> maxByOption<B>(
  1. Function1<A, B> f,
  2. Order<B> order
)
inherited

Finds the largest element in this collection by applying f to each element and using the given Order to find the greatest.

If this collection is empty, None is returned.

Implementation

Option<A> maxByOption<B>(Function1<A, B> f, Order<B> order) => _minMaxByOption(f, order.max);