tupled property

ValidatedNel<E, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19)> get tupled

If all items of this tuple are a Valid, the respective items are turned into a tuple and returned as a ValidatedNel. If any item is an Invalid, the accumulation of all Invalid instances is returned.

Implementation

ValidatedNel<
  E,
  (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19)
>
get tupled => init.tupled.product(last).map((t) => t.$1.appended(t.$2));