Tuple5EitherOps<E, T1, T2, T3, T4, T5> extension

Provides additional functions on tuple with 5 Eithers.

on

Properties

tupled Either<E, (T1, T2, T3, T4, T5)>

Available on (Either<E, T1>, Either<E, T2>, Either<E, T3>, Either<E, T4>, Either<E, T5>), provided by the Tuple5EitherOps extension

If all items of this tuple are a Right, the respective items are turned into a tuple and returned as a Right. If any item is a Left, the first Left encountered is returned.
no setter

Methods

mapN<T6>(Function5<T1, T2, T3, T4, T5, T6> fn) Either<E, T6>

Available on (Either<E, T1>, Either<E, T2>, Either<E, T3>, Either<E, T4>, Either<E, T5>), provided by the Tuple5EitherOps extension

Applies fn to the values of each respective tuple member if all values are a Right. If any item is a Left, the first Left encountered will be returned.