Tuple7EitherOps<E, T1, T2, T3, T4, T5, T6, T7> extension
Provides additional functions on tuple with 7 Eithers.
Properties
-
tupled
→ Either<
E, (T1, T2, T3, T4, T5, T6, T7)> -
Available on (Either<
If all items of this tuple are a Right, the respective items are turned into a tuple and returned as a Right. If any item is a Left, the first Left encountered is returned.E, T1> , Either<E, T2> , Either<E, T3> , Either<E, T4> , Either<E, T5> , Either<E, T6> , Either<E, T7> ), provided by the Tuple7EitherOps extensionno setter
Methods
-
mapN<
T8> (Function7< T1, T2, T3, T4, T5, T6, T7, T8> fn) → Either<E, T8> -
Available on (Either<
AppliesE, T1> , Either<E, T2> , Either<E, T3> , Either<E, T4> , Either<E, T5> , Either<E, T6> , Either<E, T7> ), provided by the Tuple7EitherOps extensionfnto the values of each respective tuple member if all values are a Right. If any item is a Left, the first Left encountered will be returned.