zip<B> method
Returns a new collection that combines corresponding elements from this
collection and that as a tuple. The length of the returned collection will
be the minimum of this collections size and the size of that.
Implementation
@override
ArrayDeque<(A, B)> zip<B>(RIterableOnce<B> that) => from(super.zip(that));