zipAll<B> method
Returns a new collection that combines corresponding elements from this
collection and that as a tuple. The length of the returned collection
will be the maximum of this collections size and thes size of that. If
this collection is shorter than that, thisElem will be used to fill in
the resulting collection. If that is shorter, thatElem will be used to
will in the resulting collection.
Implementation
@override
ArrayDeque<(A, B)> zipAll<B>(RIterableOnce<B> that, A thisElem, B thatElem) =>
from(super.zipAll(that, thisElem, thatElem));