Function6Ops<T0, T1, T2, T3, T4, T5, T6> extension
Provides additional functions on functions with 6 parameters.
- on
-
- Function6<
T0, T1, T2, T3, T4, T5, T6>
- Function6<
Properties
-
curried
→ Function6C<
T0, T1, T2, T3, T4, T5, T6> -
Available on Function6<
Return the curried form of this function.T0, T1, T2, T3, T4, T5, T6> , provided by the Function6Ops extensionno setter -
tupled
→ Function1<
(T0, T1, T2, T3, T4, T5), T6> -
Available on Function6<
Returns a function that takes a tuple of parameters rather than individual parameters.T0, T1, T2, T3, T4, T5, T6> , provided by the Function6Ops extensionno setter
Methods
-
andThen<
T7> (Function1< T6, T7> fn) → Function6<T0, T1, T2, T3, T4, T5, T7> -
Available on Function6<
Composes this function with the provided function, this function being applied first.T0, T1, T2, T3, T4, T5, T6> , provided by the Function6Ops extension -
compose<
T7> (Function1< T7, (T0, T1, T2, T3, T4, T5)> fn) → Function1<T7, T6> -
Available on Function6<
Composes this function with the provided function, this function being applied first.T0, T1, T2, T3, T4, T5, T6> , provided by the Function6Ops extension