scanLeft<B> method
Returns a new collection of running totals starting with z.
The first element of the result is z; each subsequent element is the
result of applying op to the previous total and the next element.
Implementation
@override
IList<B> scanLeft<B>(B z, Function2<B, A, B> op) => super.scanLeft(z, op).toIList();