MQueue<A> class
A mutable FIFO queue backed by ArrayDeque.
Use enqueue / enqueueAll to add elements at the back and dequeue to remove from the front. front peeks at the head without removing it.
final q = MQueue<int>();
q.enqueue(1).enqueue(2);
q.dequeue(); // 1
q.front; // 2
- Inheritance
-
- Object
- ArrayDeque<
A> - MQueue
- Available extensions
Properties
-
array
↔ Array<
A> -
getter/setter pairinherited
- end ↔ int
-
getter/setter pairinherited
- front → A
-
Returns the front element without removing it.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- head → A
-
Returns the first element of this collection, or throws if it is empty.
no setterinherited
-
headOption
→ Option<
A> -
Returns the first element of this collection as a Some if non-empty.
If this collction is empty, None is returned.
no setterinherited
-
init
→ ArrayDeque<
A> -
Returns all elements from this collection except the last. If this
collection is empty, an empty collection is returned.
no setterinherited
-
inits
→ RIterator<
ArrayDeque< A> > -
Returns an iterator of all potential tails of this collection, starting
with the entire collection and ending with an empty one.
no setterinherited
- isEmpty → bool
-
Whether this collection contains no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection contains at least one element.
no setterinherited
- isTraversableAgain → bool
-
Whether this collection can be traversed more than once.
no setterinherited
-
iterator
→ RIterator<
A> -
Returns an RIterator over the elements of this collection.
no setterinherited
- knownSize → int
-
Returns the number of elements in this collection, if that number is
already known. If not, -1 is returned.
no setterinherited
- last → A
-
Returns the last element of this collection, or throws if it is empty.
no setterinherited
-
lastOption
→ Option<
A> -
Returns the last element of this collection as a Some, or None if this
collection is empty.
no setterinherited
- length → int
-
The number of elements in this sequence.
no setterinherited
- nonEmpty → bool
-
Whether this collection contains at least one element.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Returns the number of elements in this collection.
no setterinherited
- start ↔ int
-
getter/setter pairinherited
-
tail
→ ArrayDeque<
A> -
Returns a new collection with the first element removed. If this
collection is empty, an empty collection is returned.
no setterinherited
-
tails
→ RIterator<
ArrayDeque< A> > -
Returns an iterator of all potential tails of this collection, starting
with the entire collection and ending with an empty one.
no setterinherited
Methods
-
addAll(
RIterableOnce< A> elems) → ArrayDeque<A> -
Appends all
elemsand returnsthis.inherited -
addOne(
A elem) → ArrayDeque< A> -
Appends
elemand returnsthis.inherited -
append(
A elem) → ArrayDeque< A> -
Alias for addOne.
inherited
-
appendAll(
RIterableOnce< A> elems) → ArrayDeque<A> -
Alias for addAll.
inherited
-
appended(
A elem) → ArrayDeque< A> -
Returns a new Seq, with the given
elemadded to the end.inherited -
appendedAll(
RIterableOnce< A> suffix) → ArrayDeque<A> -
Returns a new Seq, with
elemsadded to the end.inherited -
canEqual(
Object other) → bool -
inherited
-
clear(
) → void -
Removes all elements from this buffer.
inherited
-
collect<
B> (Function1< A, Option< f) → ArrayDeque<B> >B> -
Returns a new collection by applying
fto each element an only keeping results of type Some.inherited -
collectFirst<
B> (Function1< A, Option< f) → Option<B> >B> -
Applies
fto each element of this collection, returning the first element that results in a Some, if any.inherited -
combinations(
int n) → RIterator< ArrayDeque< A> > -
Returns an Iterator that will produce all combinations of elements from
this sequence of size
nin order.inherited -
concat(
covariant RIterableOnce< A> suffix) → ArrayDeque<A> -
Returns a copy of this collection, with
elemsadded to the end.inherited -
contains(
A elem) → bool -
Returns true, if any element of this collection equals
elem.inherited -
containsSlice(
RSeq< A> that) → bool -
Returns true if
thatis contained in this collection, in order.inherited -
copyToArray(
Array< A> xs, [int start = 0, int? n]) → int -
Copies elements into
xsstarting atstart, writing at mostnelements (or all remaining capacity whennis omitted).inherited -
corresponds<
B> (covariant RIterable< B> that, Function2<A, B, bool> p) → bool -
Returns true if this collection has the same size as
thatand each corresponding element from this andthatsatisfies the given predicatep.inherited -
count(
Function1< A, bool> p) → int -
Return the number of elements in this collection that satisfy the given
predicate.
inherited
-
dequeue(
) → A - Removes and returns the front element. Throws if empty.
-
dequeueAll(
Function1< A, bool> p) → RSeq<A> -
Removes and returns all elements satisfying
p. -
dequeueFirst(
Function1< A, bool> p) → Option<A> -
Removes and returns the first element satisfying
p, or None if none. -
dequeueWhile(
Function1< A, bool> p) → RSeq<A> -
Removes and returns all leading elements satisfying
p. -
diff(
RSeq< A> that) → ArrayDeque<A> -
Returns a new collection with the difference of this and
that, i.e. all elements that appear in only this collection.inherited -
distinct(
) → ArrayDeque< A> -
Returns a new collection where every element is distinct according to
equality.
inherited
-
distinctBy<
B> (Function1< A, B> f) → ArrayDeque<A> -
Returns a new collection where every element is distinct according to
the application of
fto each element.inherited -
drop(
int n) → ArrayDeque< A> -
Returns a new collection with the first
nelements removed.inherited -
dropInPlace(
int n) → ArrayDeque< A> -
Removes the first
nelements in place and returnsthis.inherited -
dropRight(
int n) → ArrayDeque< A> -
Return a new collection with the last
nelements removed.inherited -
dropRightInPlace(
int n) → ArrayDeque< A> -
Removes the last
nelements in place and returnsthis.inherited -
dropWhile(
Function1< A, bool> p) → ArrayDeque<A> -
Returns a new collection with leading elements satisfying
premoved.inherited -
dropWhileInPlace(
Function1< A, bool> p) → ArrayDeque<A> -
Removes leading elements satisfying
pin place and returnsthis.inherited -
endsWith(
RIterable< A> that) → bool -
Returns true if the end of this collection has the same elements in order
as
that. Otherwise, false is returned.inherited -
enqueue(
A elem) → MQueue< A> -
Adds
elemat the back of the queue and returnsthis. -
enqueueAll(
RIterableOnce< A> elems) → MQueue<A> -
Adds all
elemsat the back of the queue and returnsthis. -
exists(
Function1< A, bool> p) → bool -
Returns true if any element of this collection satisfies the given
predicate, false if no elements satisfy it.
inherited
-
filter(
Function1< A, bool> p) → ArrayDeque<A> -
Returns a new collection containing only elements that satisfy
p.inherited -
filterNot(
Function1< A, bool> p) → ArrayDeque<A> -
Returns a new collection containing only elements that do not
satisfy
p.inherited -
find(
Function1< A, bool> p) → Option<A> -
Returns the first element from this collection that satisfies the given
predicate
p. If no element satisfiesp, None is returned.inherited -
findLast(
Function1< A, bool> p) → Option<A> -
Returns the last element satisfying
pasSome, or None if none.inherited -
flatMap<
B> (covariant Function1< A, RIterableOnce< f) → ArrayDeque<B> >B> -
Returns a new collection by applying
fto each element and concatenating the results.inherited -
flatten(
) → RIterable< A> -
Available on RIterable<
Concatenates all inner iterables into a single IList.RIterable< , provided by the RIterableNested2Ops extensionA> > -
fold(
A init, Function2< A, A, A> op) → A -
Alias for foldLeft with a same-type accumulator.
inherited
-
foldLeft<
B> (B z, Function2< B, A, B> op) → B -
Returns a summary value by applying
opto all elements of this collection, moving from left to right. The fold uses a seed value ofz.inherited -
foldRight<
B> (B z, Function2< A, B, B> op) → B -
Returns a summary value by applying
opto all elements of this collection, moving from right to left. The fold uses a seed value ofz.inherited -
forall(
Function1< A, bool> p) → bool -
Returns true if all elements of this collection satisfy the given
predicate, false if any elements do not.
inherited
-
foreach<
U> (Function1< A, U> f) → void -
Applies
fto each element of this collection, discarding any resulting values.inherited -
groupBy<
K> (Function1< A, K> f) → IMap<K, ArrayDeque< A> > -
Partitions all elements of this collection by applying
fto each element and accumulating duplicate keys in the returned IMap.inherited -
grouped(
int size) → RIterator< ArrayDeque< A> > -
Returns a new iterator where each element is a collection of
sizeelements from the original collection. The last element may contain less thansizeelements.inherited -
groupMap<
K, B> (Function1< A, K> key, Function1<A, B> f) → IMap<K, ArrayDeque< B> > -
Creates a new map by generating a key-value pair for each elements of this
collection using
keyandf. Any elements that generate the same key will have the resulting values accumulated in the returned map.inherited -
groupMapReduce<
K, B> (Function1< A, K> key, Function1<A, B> f, Function2<B, B, B> reduce) → IMap<K, B> -
Partitions all elements of this collection by applying
keyto each element. Additionallyfis applied to each element to generate a value. If multiple values are generating for the same key, those values will be combined usingreduce.inherited -
indexOf(
A elem, [int from = 0]) → Option< int> -
Returns the first index, if any, where the element at that index equals
elem. If no index containselem, None is returned.inherited -
indexOfSlice(
RSeq< A> that, [int from = 0]) → Option<int> -
Finds the first index in this collection where the next sequence of
elements is equal to
that. Ifthatcannot be found in this collection, None is returned.inherited -
indexWhere(
Function1< A, bool> p, [int from = 0]) → Option<int> -
Returns the index of the first element that satisfies the predicate
p. If no element satisfies, None is returned.inherited -
indices(
) → Range -
Returns a range of all indices of this sequence
inherited
-
insert(
int idx, A elem) → void -
Inserts
elemat positionidx, shifting later elements right.inherited -
insertAll(
int idx, RIterableOnce< A> elems) → void -
Inserts all
elemsstarting at positionidx.inherited -
intersect(
RSeq< A> that) → ArrayDeque<A> -
Returns a new collection with the intersection of this and
that, i.e. all elements that appear in both collections.inherited -
intersperse(
A x) → ArrayDeque< A> -
Returns a new collection with
sepinserted between each element.inherited -
isDefinedAt(
int idx) → bool -
Returns true if this collection has an element at the given
idx.inherited -
lastIndexOf(
A elem, [int end = 2147483647]) → Option< int> -
Returns the last index, if any, where the element at that index equals
elem. If no index containselem, None is returned.inherited -
lastIndexOfSlice(
RSeq< A> that, [int end = 2147483647]) → Option<int> -
Finds the last index in this collection where the next sequence of
elements is equal to
that. Ifthatcannot be found in this collection, None is returned.inherited -
lastIndexWhere(
Function1< A, bool> p, [int end = 2147483647]) → Option<int> -
Returns the index of the last element that satisfies the predicate
p. If no element satisfies, None is returned.inherited -
lift(
int ix) → Option< A> -
Returns the element at index
ixas a Some. Ifixis outside the range of this collection, None is returned.inherited -
map<
B> (Function1< A, B> f) → RSeq<B> -
Returns a new collection by applying
fto each element.inherited -
maxByOption<
B> (Function1< A, B> f, Order<B> order) → Option<A> -
Finds the largest element in this collection by applying
fto each element and using the given Order to find the greatest.inherited -
maxOption(
Order< A> order) → Option<A> -
Finds the largest element in this collection according to the given
Order.
inherited
-
minByOption<
B> (Function1< A, B> f, Order<B> order) → Option<A> -
Finds the smallest element in this collection by applying
fto each element and using the given Order to find the greatest.inherited -
minOption(
Order< A> order) → Option<A> -
Finds the largest element in this collection according to the given
Order.
inherited
-
mkString(
{String? start, String? sep, String? end}) → String -
Returns a String by using each elements toString(), adding
sepbetween each element. Ifstartis defined, it will be prepended to the resulting string. Ifendis defined, it will be appended to the resulting string.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padTo(
int len, A elem) → ArrayDeque< A> -
Returns a new collection with a length of at least
len.inherited -
padToInPlace(
int len, A elem) → ArrayDeque< A> -
Appends
elemuntil length equalslen, then returnsthis.inherited -
partition(
Function1< A, bool> p) → (ArrayDeque<A> , ArrayDeque<A> ) -
Returns 2 collections as a tuple where the first tuple element will be a
collection of elements that satisfy the given predicate
p. The second item of the returned tuple will be elements that do not satisfyp.inherited -
partitionMap<
A1, A2> (Function1< A, Either< f) → (ArrayDeque<A1, A2> >A1> , ArrayDeque<A2> ) -
Applies
fto each element of this collection and returns a separate collection for all applications resulting in a Left and Right respectively.inherited -
patch(
int from, RIterableOnce< A> other, int replaced) → ArrayDeque<A> -
Returns a new collection with
replacedelements starting atfromreplaced by the elements ofother.inherited -
patchInPlace(
int from, RIterableOnce< A> patch, int replaced) → ArrayDeque<A> -
Replaces
replacedelements starting atfromwithpatchin place.inherited -
permutations(
) → RIterator< IndexedSeq< A> > -
Returns an Iterator that will emit all possible permutations of the
elements in this collection.
inherited
-
prepend(
A elem) → ArrayDeque< A> -
Prepends
elemand returnsthis.inherited -
prependAll(
RIterableOnce< A> elems) → ArrayDeque<A> -
Prepends all
elemsand returnsthis.inherited -
prepended(
A elem) → IndexedSeq< A> -
Returns a new collection with
elemadded to the beginning.inherited -
prependedAll(
RIterableOnce< A> prefix) → IndexedSeq<A> -
Returns a new collection with all
elemsadded to the beginning.inherited -
product(
) → double -
Available on RIterableOnce<
Returns the product of all elements in this listdouble> , provided by the RIterableDoubleOps extension -
product(
) → int -
Available on RIterableOnce<
Returns the product of all elements in this listint> , provided by the RIterableIntOps extension -
reduce(
Function2< A, A, A> op) → A -
Reduces this collection to a single value by applying
opleft to right.inherited -
reduceLeft(
Function2< A, A, A> op) → A -
Reduces from left to right. Throws if empty.
inherited
-
reduceLeftOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving left to right.inherited -
reduceOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving left to right.inherited -
reduceRight(
Function2< A, A, A> op) → A -
Reduces from right to left. Throws if empty.
inherited
-
reduceRightOption(
Function2< A, A, A> op) → Option<A> -
Returns a summary values of all elements of this collection by applying
fto each element, moving right to left.inherited -
remove(
int idx) → A -
Removes and returns the element at
idx.inherited -
removeAll(
Function1< A, bool> p) → RSeq<A> -
Removes and returns all elements satisfying
pin FIFO order.inherited -
removeAt(
int idx) → ArrayDeque< A> -
Returns a new collection with the element at
idxremoved.inherited -
removeFirst(
Function1< A, bool> p, [int from = 0]) → Option<A> -
Removes the first element satisfying
pat or afterfromand returnsSome(element), orNoneif no such element exists.inherited -
removeHead(
{bool resizeInternalRepr = false}) → A -
Removes and returns the first element.
inherited
-
removeHeadOption(
{bool resizeInternalRepr = false}) → Option< A> -
Removes and returns the first element wrapped in
Some, or returnsNonewhen empty.inherited -
removeHeadWhile(
Function1< A, bool> p) → RSeq<A> -
Removes and returns all leading elements satisfying
p.inherited -
removeLast(
{bool resizeInternalRepr = false}) → A -
Removes and returns the last element.
inherited
-
removeLastOption(
{bool resizeInternalRepr = false}) → Option< A> -
Removes and returns the last element wrapped in
Some, or returnsNonewhen empty.inherited -
removeN(
int idx, int count) → void -
Removes
countelements starting atidx.inherited -
reverse(
) → ArrayDeque< A> -
Returns a new collection with the order of the elements reversed.
inherited
-
reverseIterator(
) → RIterator< A> -
Returns an iterator that will emit all elements in this collection, in
reverse order.
inherited
-
sameElements(
RIterable< A> that) → bool -
Returns true if this collection has the same elements, in the same order,
as
that.inherited -
scan<
B> (B z, Function2< B, A, B> op) → ArrayDeque<B> -
Alias for scanLeft.
inherited
-
scanLeft<
B> (B z, Function2< B, A, B> op) → ArrayDeque<B> -
Returns a new collection of running totals starting with
z.inherited -
scanRight<
B> (B z, Function2< A, B, B> op) → ArrayDeque<B> -
Returns a new collection of running totals starting with
z, traversing from right to left.inherited -
segmentLength(
Function1< A, bool> p, [int from = 0]) → int -
Returns the length of the longest prefix starting at
fromwhere every element satisfiesp.inherited -
slice(
int from, int until) → ArrayDeque< A> -
Returns a new collection containing elements in the range
[from, until).inherited -
sliceInPlace(
int start, int end) → ArrayDeque< A> -
Keeps only the elements in
[start, end)in place and returnsthis.inherited -
sliding(
int size, [int step = 1]) → RIterator< ArrayDeque< A> > -
Returns an iterator where elements are fixed size chunks of size
nof the original collection. Each chunk is calculated by sliding a 'window' of sizenover the original collection, moving the windowstepelements at a time.inherited -
sortBy<
B> (Order< B> order, Function1<A, B> f) → ArrayDeque<A> -
Returns a new collection that is sorted according to
orderafter applyingfto each element in this collection.inherited -
sorted(
Order< A> order) → ArrayDeque<A> -
Returns a new collection that is sorted according to
order.inherited -
sortWith(
Function2< A, A, bool> lt) → ArrayDeque<A> -
Returns a new collection sorted using the provided function
ltwhich is used to determine if one element is less than the other.inherited -
span(
Function1< A, bool> p) → (ArrayDeque<A> , ArrayDeque<A> ) -
Returns two collections: elements before and starting from the first
element that does not satisfy
p.inherited -
splitAt(
int n) → (RSeq< A> , RSeq<A> ) -
Returns two collections: the first
nelements and the remainder.inherited -
startsWith(
RIterableOnce< A> that, [int offset = 0]) → bool -
Returns true if the beginning of this collection corresponds with
that.inherited -
subtractOne(
A x) → ArrayDeque< A> -
Removes the first occurrence of
xand returnsthis.inherited -
sum(
) → double -
Available on RIterableOnce<
Returns the sum of all elements in this listdouble> , provided by the RIterableDoubleOps extension -
sum(
) → int -
Available on RIterableOnce<
Returns the sum of all elements in this listint> , provided by the RIterableIntOps extension -
take(
int n) → ArrayDeque< A> -
Returns a new collection containing only the first
nelements.inherited -
takeInPlace(
int n) → ArrayDeque< A> -
Keeps only the first
nelements in place and returnsthis.inherited -
takeRight(
int n) → ArrayDeque< A> -
Returns a new collection with the last
nelements of this collection. Ifnis greater than the size of this collection, the original collection is returned.inherited -
takeRightInPlace(
int n) → ArrayDeque< A> -
Keeps only the last
nelements in place and returnsthis.inherited -
takeWhile(
Function1< A, bool> p) → ArrayDeque<A> -
Returns a new collection of leading elements that satisfy
p.inherited -
takeWhileInPlace(
Function1< A, bool> p) → ArrayDeque<A> -
Keeps only the leading elements satisfying
pin place and returnsthis.inherited -
tapEach<
U> (Function1< A, U> f) → ArrayDeque<A> -
Applies
fto each element in this collection, discarding any results and returns this collection.inherited -
toIList(
) → IList< A> -
Returns an IList with the same elements as this collection.
inherited
-
toIMap(
) → IMap< A, B> -
Available on RIterable<
Creates a new IMap where each tuple element of this list is used to create a key and value respectively.(A, B)> , provided by the RIterableTuple2Ops extension -
toIndexedSeq(
) → IndexedSeq< A> -
Returns an IndexedSeq with the same elements as this collection.
inherited
-
toISet(
) → ISet< A> -
Returns an ISet with the same elements as this collection, duplicates
removed.
inherited
-
toIVector(
) → IVector< A> -
Returns an IVector with the same elements as this collection.
inherited
-
toList(
{bool growable = true}) → List< A> -
Returns a new List with the same elements as this collection.
inherited
-
toSeq(
) → RSeq< A> -
Returns a RSeq with the same elements as this collection.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
traverseEither<
B, C> (Function1< A, Either< f) → Either<B, C> >B, ArrayDeque< C> > -
Applies
fto each element of this RSeq and collects the results into a new collection. If Left is encountered for any element, that result is returned and any additional elements will not be evaluated.inherited -
traverseOption<
B> (Function1< A, Option< f) → Option<B> >ArrayDeque< B> > -
Applies
fto each element of this RSeq and collects the results into a new collection. If None is encountered for any element, that result is returned and any additional elements will not be evaluated.inherited -
trimToSize(
) → void -
Shrinks the internal array to exactly fit the current number of elements.
inherited
-
unzip(
) → (IndexedSeq< A> , IndexedSeq<B> ) -
Available on IndexedSeq<
(A, B)> , provided by the IndexedSeqTuple2Ops extension -
unzip(
) → (RIterable< A> , RIterable<B> ) -
Available on RIterable<
Splits a collection of pairs into two separate collections.(A, B)> , provided by the RibsIterableTuple2Ops extension -
update(
int idx, A elem) → void -
Replaces the element at
idxwithelem.inherited -
updated(
int index, A elem) → ArrayDeque< A> -
Returns a new collection with the element at
indexreplaced byelem.inherited -
zip<
B> (RIterableOnce< B> that) → ArrayDeque<(A, B)> -
Returns a new collection that combines corresponding elements from this
collection and
thatas a tuple. The length of the returned collection will be the minimum of this collections size and the size ofthat.inherited -
zipAll<
B> (RIterableOnce< B> that, A thisElem, B thatElem) → ArrayDeque<(A, B)> -
Returns a new collection that combines corresponding elements from this
collection and
thatas a tuple. The length of the returned collection will be the maximum of this collections size and thes size ofthat. If this collection is shorter thanthat,thisElemwill be used to fill in the resulting collection. Ifthatis shorter,thatElemwill be used to will in the resulting collection.inherited -
zipWithIndex(
) → ArrayDeque< (A, int)> -
Return a new collection with each element of this collection paired with
it's respective index.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int idx) → A -
Returns the element at index
idx.inherited
Static Methods
-
empty<
A> () → MQueue< A> -
Returns an empty MQueue.
override
-
from<
A> (RIterableOnce< A> source) → MQueue<A> -
Creates an MQueue from a RIterableOnce, preserving order.
override