minByOption<B> method
Finds the smallest element in this collection by applying f to each element
and using the given Order to find the greatest.
If this collection is empty, None is returned.
Implementation
Option<A> minByOption<B>(Function1<A, B> f, Order<B> order) => _minMaxByOption(f, order.min);