mapN<T20> method
ValidatedNel<E, T20>
mapN<T20>(
- Function19<
T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20> fn
Applies fn to the values of each respective tuple member if all values
are a Valid. If any item is an Invalid, the accumulation of all
Invalid instances is returned.
Implementation
ValidatedNel<E, T20> mapN<T20>(
Function19<
T1,
T2,
T3,
T4,
T5,
T6,
T7,
T8,
T9,
T10,
T11,
T12,
T13,
T14,
T15,
T16,
T17,
T18,
T19,
T20
>
fn,
) => tupled.map(fn.tupled);